==> babel-plugin-direct-import-0.6.1.tgz: package/dist-src/utils/getConfigExports.js <==
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { parse, types } from '@babel/core';
import { readFileSync } from 'fs';
import { dirname, join, sep } from 'path';
import { assertNotNull } from "./asserts.js";
import { resolveModule } from "./resolveModule.js";

function toRelativeSource(filePath) {
  var pathChunks = filePath.split(sep);
  var relativeChunks = pathChunks.slice(pathChunks.lastIndexOf('node_modules') + 1);
  return relativeChunks.join('/');
}

function resolveIndexPath(name, indexFile) {
  if (!indexFile) {
    var _indexFilePath = resolveModule(name);

    assertNotNull(_indexFilePath, "failed to find 'indexFile' of '%s'.", name);
    return _indexFilePath;
  }

  var pkgJSON = resolveModule("".concat(name, "/package.json"));
  assertNotNull(pkgJSON, "failed to resolve package.json for '%s'", name);
  var pkgDir = dirname(pkgJSON);
  var indexFilePath = resolveModule(join(pkgDir, indexFile));
  assertNotNull(indexFilePath, "failed to resolve 'indexFile' specified for '%s'.", name);
  return indexFilePath;
}

function fulfillExports(exports, filePath) {
  var content = readFileSync(filePath, 'utf-8');
  var ast = parse(content, {
    filename: filePath,
    sourceType: 'module'
  });
  var program = !ast ? null : ast.type === 'File' ? ast.program : ast;
  assertNotNull(program, "failed to parse '%s'.", filePath);
  var fileDir = dirname(filePath);
  var imports = new Map();

  for (var node of program.body) {
    if (types.isImportDeclaration(node)) {
      var sourcePath = resolveModule(node.source.value, fileDir);

      if (!sourcePath) {
        continue;
      }

      for (var specifier of node.specifiers) {
        imports.set(specifier.local.name, {
          external: types.isImportNamespaceSpecifier(specifier) ? '*' : types.isImportDefaultSpecifier(specifier) ? 'default' : specifier.imported.name,
          internal: specifier.local.name,
          source: toRelativeSource(sourcePath)
        });
      }
    } else if (types.isExportNamedDeclaration(node)) {
      var nodeDeclaration = node.declaration;

      if (types.isVariableDeclaration(nodeDeclaration)) {
        for (var declaration of nodeDeclaration.declarations) {
          if (types.isIdentifier(declaration.id) && types.isIdentifier(declaration.init)) {
            var external = declaration.id.name;
            var internal = declaration.init.name;
            var imported = imports.get(internal);

            if (imported) {
              exports.set(external, {
                external,
                source: imported.source,
                internal: imported.external
              });
            }
          }
        }
      }

      var _sourcePath = !node.source ? null : resolveModule(node.source.value, fileDir);

      for (var _specifier of node.specifiers) {
        if (_specifier.type === 'ExportSpecifier') {
          var _internal = _specifier.local.name;
          var _external = _specifier.exported.name;

          if (_sourcePath) {
            exports.set(_external, {
              internal: _internal,
              external: _external,
              source: toRelativeSource(_sourcePath)
            });
          } else {
            var _imported = imports.get(_internal);

            if (_imported) {
              exports.set(_external, _objectSpread({}, _imported, {
                external: _external
              }));
            }
          }
        }
      }
    } else if (types.isExportAllDeclaration(node)) {
      var _sourcePath2 = resolveModule(node.source.value, fileDir);

      assertNotNull(_sourcePath2, 'failed to resolve %s', _sourcePath2);
      fulfillExports(exports, _sourcePath2);
    }
  }
}

export function getConfigExports(config) {
  var indexPath = resolveIndexPath(config.name, config.indexFile);
  var exports = new Map();
  fulfillExports(exports, indexPath);
  return exports;
}

==> babel-plugin-direct-import-0.6.2.tgz: package/dist-src/utils/getConfigExports.js <==
import { parse, types } from '@babel/core';
import { readFileSync } from 'fs';
import { dirname, join, sep } from 'path';
import { assertNotNull } from "./asserts.js";
import { resolveModule } from "./resolveModule.js";

function toRelativeSource(filePath) {
  var pathChunks = filePath.split(sep);
  var relativeChunks = pathChunks.slice(pathChunks.lastIndexOf('node_modules') + 1);
  return relativeChunks.join('/');
}

function resolveIndexPath(name, indexFile) {
  if (!indexFile) {
    var _indexFilePath = resolveModule(name);

    assertNotNull(_indexFilePath, "failed to find 'indexFile' of '%s'.", name);
    return _indexFilePath;
  }

  var pkgJSON = resolveModule("".concat(name, "/package.json"));
  assertNotNull(pkgJSON, "failed to resolve package.json for '%s'", name);
  var pkgDir = dirname(pkgJSON);
  var indexFilePath = resolveModule(join(pkgDir, indexFile));
  assertNotNull(indexFilePath, "failed to resolve 'indexFile' specified for '%s'.", name);
  return indexFilePath;
}

function fulfillExports(exports, filePath) {
  var content = readFileSync(filePath, 'utf-8');
  var ast = parse(content, {
    filename: filePath,
    sourceType: 'module'
  });
  var program = !ast ? null : ast.type === 'File' ? ast.program : ast;
  assertNotNull(program, "failed to parse '%s'.", filePath);
  var fileDir = dirname(filePath);
  var imports = new Map();

  for (var node of program.body) {
    if (types.isImportDeclaration(node)) {
      var sourcePath = resolveModule(node.source.value, fileDir);

      if (!sourcePath) {
        continue;
      }

      for (var specifier of node.specifiers) {
        imports.set(specifier.local.name, {
          source: toRelativeSource(sourcePath),
          imported: types.isImportNamespaceSpecifier(specifier) ? '*' : types.isImportDefaultSpecifier(specifier) ? 'default' : specifier.imported.name
        });
      }
    } else if (types.isExportNamedDeclaration(node)) {
      var nodeDeclaration = node.declaration;

      if (types.isVariableDeclaration(nodeDeclaration)) {
        for (var declaration of nodeDeclaration.declarations) {
          if (types.isIdentifier(declaration.id) && types.isIdentifier(declaration.init)) {
            var external = declaration.id.name;
            var internal = declaration.init.name;
            var imported = imports.get(internal);

            if (imported) {
              exports.set(external, {
                external,
                source: imported.source,
                internal: imported.imported
              });
            }
          }
        }
      }

      var _sourcePath = !node.source ? null : resolveModule(node.source.value, fileDir);

      for (var _specifier of node.specifiers) {
        if (_specifier.type === 'ExportSpecifier') {
          var _internal = _specifier.local.name;
          var _external = _specifier.exported.name;

          if (_sourcePath) {
            exports.set(_external, {
              internal: _internal,
              external: _external,
              source: toRelativeSource(_sourcePath)
            });
          } else {
            var _imported = imports.get(_internal);

            if (_imported) {
              exports.set(_external, {
                external: _external,
                source: _imported.source,
                internal: _imported.imported
              });
            }
          }
        }
      }
    } else if (types.isExportAllDeclaration(node)) {
      var _sourcePath2 = resolveModule(node.source.value, fileDir);

      assertNotNull(_sourcePath2, 'failed to resolve %s', _sourcePath2);
      fulfillExports(exports, _sourcePath2);
    }
  }
}

export function getConfigExports(config) {
  var indexPath = resolveIndexPath(config.name, config.indexFile);
  var exports = new Map();
  fulfillExports(exports, indexPath);
  return exports;
}
